%smooth_weather
% Import weather data, and smooth the temperature vs time data using a
% moving window average and standard deviation.
%
% LAST UPDATED by Andy French 28/11/2019

function smooth_weather

%Fontsize
fsize = 18;

%Window size for averages
N = 1000;

%

%Import the weather data
load('met_data Nov 2019 weather.mat')

%Define t / hours since start of data and T /degC
t = t_hours; T = temp_out;

%Plot data
p = plot(t,T,'r+'); set( p, 'color',[1,0,0] ); hold on
xlabel('time /hours','fontsize',fsize);
ylabel('Temperature /^oC','fontsize',fsize);
title('Temperature vs time','fontsize',fsize); 
set( gca, 'fontsize',fsize); grid on;

%Work out moving average and standard deviation
for n=1:length(T)-2*N
    window_start = n;
    window_stop = n + N - 1;
    W = T( window_start : window_stop );
    T_av(n) = mean(W); 
    T_std(n) = std(W);
end

%Plot a semitransparent patch representing the moving average
tt = t( N+1:length(T)-N );
pp = patch( [tt,fliplr(tt)],...
[T_av + T_std, fliplr( T_av - T_std ) ],'b' );
set(pp,'facealpha',0.5);

%Add moving average to plot
plot( tt, T_av, 'b-' );

%Print graph to PNG
print( gcf, 'T vs time.png','-dpng','-r300' );
close(gcf);

%End of code